pub struct Renderer<COMP>where
COMP: BaseComponent + 'static,{ /* private fields */ }Expand description
The Yew Renderer.
This is the main entry point of a Yew application.
Implementations
Sourceimpl<COMP> Renderer<COMP>where
COMP: BaseComponent + 'static,
impl<COMP> Renderer<COMP>where
COMP: BaseComponent + 'static,
Sourcepub fn with_props(props: <COMP as BaseComponent>::Properties) -> Renderer<COMP>
pub fn with_props(props: <COMP as BaseComponent>::Properties) -> Renderer<COMP>
Creates a Renderer that renders into the document body with custom properties.
Sourcepub fn with_root_and_props(
root: Element,
props: <COMP as BaseComponent>::Properties,
) -> Renderer<COMP>
pub fn with_root_and_props( root: Element, props: <COMP as BaseComponent>::Properties, ) -> Renderer<COMP>
Creates a Renderer that renders into a custom root with custom properties.